package com.isu.gaswellwatch.vo.command.knpcv1;

import com.isu.gaswellwatch.dto.modbus.ModbusCommandDto;
import com.isu.gaswellwatch.vo.command.Command;
import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.Setter;
import lombok.experimental.SuperBuilder;
import org.apache.commons.lang3.ObjectUtils;

import java.io.Serial;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

/**
 * 运行模式：
 * 0：手动模式
 * 1：定时器模式
 * 2：计时器模式
 * 3：压力模式
 * 4：柱塞模式
 * 5：时压模式
 *
 * @author <a href="mailto:scwsl@foxmail.com">王仕龙</a>
 * 2024/11/26 20:09
 */
@Getter
@Setter
@SuperBuilder
@AllArgsConstructor
public abstract class ChangeRunMode extends Command {
    @Serial
    private static final long serialVersionUID = 7882661805502297673L;

    private int runMode;

    @Override
    public boolean validate() {
        return super.validate() && this.runMode >= 0 && this.runMode <= 5;
    }

    @Override
    protected final Collection<ModbusCommandDto> builderModbusCommand() {
        Collection<ModbusCommandDto> subCommands = this.builderSubModbusCommand();
        List<ModbusCommandDto> resultCommands = new ArrayList<>();
        if (ObjectUtils.isNotEmpty(subCommands)) {
            resultCommands.addAll(subCommands);
        }
        resultCommands.add(ModbusCommandDto.builder().command("01060064000" + this.runMode).length(16).build());
        return resultCommands;
    }

    protected abstract Collection<ModbusCommandDto> builderSubModbusCommand();

}
